@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2021-2023 Valve Corporation
- * Copyright (C) 2021-2023 LunarG, Inc.
+ * Copyright (C) 2021-2024 Valve Corporation
+ * Copyright (C) 2021-2024 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,9 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Author: Ziga Markus <ziga@lunarg.com>
- * Author: Christophe Riccio <christophe@lunarg.com>
- * Author: Mark Lobodzinski <mark@lunarg.com>
+ * Authors:
+ * - Ziga Markus <ziga@lunarg.com>
+ * - Christophe Riccio <christophe@lunarg.com>
+ * - Mark Lobodzinski <mark@lunarg.com>
  */
 
 #include <vulkan/vulkan_core.h>
@@ -41,16 +42,20 @@ class LayerTests : public VkTestFramework {
 TEST_F(LayerTests, TestDesktop2023) {
     TEST_DESCRIPTION("Test specifying device extensions to be excluded from being reported by the device");
 
-    static const char* profile_file_data = JSON_PROFILES_PATH "VP_LUNARG_desktop_baseline_2023.json";
+    static const char* profile_dir_data = JSON_PROFILES_PATH;
     static const char* profile_name_data = "VP_LUNARG_desktop_baseline_2023";
     VkBool32 emulate_portability_data = VK_TRUE;
     VkBool32 debug_fail_on_error = VK_FALSE;
+    const std::vector<const char*> debug_reports = {"DEBUG_REPORT_ERROR_BIT", "DEBUG_REPORT_WARNING_BIT",
+                                                    "DEBUG_REPORT_NOTIFICATION_BIT", "DEBUG_REPORT_DEBUG_BIT"};
 
     std::vector<VkLayerSettingEXT> settings = {
-        {kLayerName, kLayerSettingsProfileFile, VK_LAYER_SETTING_TYPE_STRING_EXT, 1, {&profile_file_data}},
+        {kLayerName, kLayerSettingsProfileDirs, VK_LAYER_SETTING_TYPE_STRING_EXT, 1, {&profile_dir_data}},
         {kLayerName, kLayerSettingsProfileName, VK_LAYER_SETTING_TYPE_STRING_EXT, 1, {&profile_name_data}},
         {kLayerName, kLayerSettingsEmulatePortability, VK_LAYER_SETTING_TYPE_BOOL32_EXT, 1, &emulate_portability_data},
-        {kLayerName, kLayerSettingsDebugFailOnError, VK_LAYER_SETTING_TYPE_BOOL32_EXT, 1, &debug_fail_on_error}};
+        {kLayerName, kLayerSettingsDebugFailOnError, VK_LAYER_SETTING_TYPE_BOOL32_EXT, 1, &debug_fail_on_error},
+        {kLayerName, kLayerSettingsDebugReports, VK_LAYER_SETTING_TYPE_STRING_EXT, static_cast<uint32_t>(debug_reports.size()), &debug_reports[0]}
+    };
 
     profiles_test::VulkanInstanceBuilder inst_builder;
     VkResult err = inst_builder.init(settings);
@@ -62,6 +67,13 @@ TEST_F(LayerTests, TestDesktop2023) {
         printf("Profile not supported on device, skipping test.\n");
         return;
     }
+
+    VkPhysicalDeviceProperties gpu_props{};
+    vkGetPhysicalDeviceProperties(gpu, &gpu_props);
+
+    ASSERT_EQ(gpu_props.limits.maxImageDimension1D, 16384);
+    ASSERT_EQ(gpu_props.limits.maxImageDimension2D, 16384);
+    ASSERT_EQ(gpu_props.limits.maxImageDimension3D, 2048);
 }
 #endif//__ANDROID__
 
@@ -266,7 +278,7 @@ TEST_F(LayerTests, TestExcludingDeviceExtensions) {
 
     VkResult err = VK_SUCCESS;
 
-    const char* profile_file_data = JSON_PROFILES_PATH "VP_LUNARG_desktop_baseline_2023.json";
+    const char* profile_file_data = JSON_PROFILES_PATH "VP_LUNARG_desktop_baseline.json";
     const char* profile_name_data = "VP_LUNARG_desktop_baseline_2023";
     VkBool32 emulate_portability_data = VK_TRUE;
     VkBool32 debug_fail_on_error = VK_FALSE;
@@ -331,7 +343,7 @@ TEST_F(LayerTests, TestExcludingDeviceExtensions) {
 TEST_F(LayerTests, TestExcludingFormats) {
     TEST_DESCRIPTION("Test specifying image formats to be excluded from being reported by the device");
 
-    const char* profile_file_data = JSON_PROFILES_PATH "VP_LUNARG_desktop_baseline_2023.json";
+    const char* profile_file_data = JSON_PROFILES_PATH "VP_LUNARG_desktop_baseline.json";
     VkBool32 emulate_portability_data = VK_TRUE;
     VkBool32 debug_fail_on_error = VK_TRUE;
     const std::vector<const char*> exclude_formats = {"VK_FORMAT_R8G8B8A8_UNORM"};
@@ -755,7 +767,7 @@ TEST_F(LayerTests, TestQueueFamilyPropertiesPartial) {
                 if ((device_qf_props[i].queueFlags & VK_QUEUE_COMPUTE_BIT) == VK_QUEUE_COMPUTE_BIT &&
                     device_qf_props[i].minImageTransferGranularity.width <= 4 &&
                     device_qf_props[i].minImageTransferGranularity.height <= 4) {
-                    device_queue_index = i;
+                    device_queue_index = static_cast<int32_t>(i);
                     break;
                 }
             }
@@ -767,8 +779,8 @@ TEST_F(LayerTests, TestQueueFamilyPropertiesPartial) {
             ASSERT_EQ(qf_props[0].minImageTransferGranularity.height, 4u);
 
             if (device_queue_index != -1) {
-                ASSERT_EQ(qf_props[0].minImageTransferGranularity.depth, device_qf_props[device_queue_index].minImageTransferGranularity.depth);
-                ASSERT_EQ(qf_props[0].timestampValidBits, device_qf_props[device_queue_index].timestampValidBits);
+                ASSERT_EQ(qf_props[0].minImageTransferGranularity.depth, device_qf_props[static_cast<std::size_t>(device_queue_index)].minImageTransferGranularity.depth);
+                ASSERT_EQ(qf_props[0].timestampValidBits, device_qf_props[static_cast<std::size_t>(device_queue_index)].timestampValidBits);
             }
         }
     }
