@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2021-2023 Valve Corporation
- * Copyright (C) 2021-2023 LunarG, Inc.
+ * Copyright (C) 2021-2024 Valve Corporation
+ * Copyright (C) 2021-2024 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,9 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Author: Ziga Markus <ziga@lunarg.com>
- * Author: Christophe Riccio <christophe@lunarg.com>
- * Author: Mark Lobodzinski <mark@lunarg.com>
+ * Authors:
+ * - Ziga Markus <ziga@lunarg.com>
+ * - Christophe Riccio <christophe@lunarg.com>
+ * - Mark Lobodzinski <mark@lunarg.com>
  */
 
 #include <vulkan/vulkan_core.h>
@@ -29,16 +30,14 @@
 
 class TestsMechanism : public VkTestFramework {
    public:
-    TestsMechanism(){};
-    ~TestsMechanism(){};
+    TestsMechanism(){}
+    ~TestsMechanism(){}
 
-    static void SetUpTestSuite() {}
-    static void TearDownTestSuite(){};
+    static void SetUpTestSuite(){}
+    static void TearDownTestSuite(){}
 };
 
-TEST_F(TestsMechanism, selecting_profile_file) {
-    TEST_DESCRIPTION("Test selecting profile from a profiles file with multiple profiles");
-
+TEST_F(TestsMechanism, check_extension) {
     VkResult err = VK_SUCCESS;
 
     profiles_test::VulkanInstanceBuilder inst_builder;
@@ -48,7 +47,7 @@ TEST_F(TestsMechanism, selecting_profile_file) {
     {
         uint32_t layer_count = 0;
         vkEnumerateInstanceLayerProperties(&layer_count, nullptr);
-        
+
         std::vector<VkLayerProperties> layer_names(layer_count);
         vkEnumerateInstanceLayerProperties(&layer_count, &layer_names[0]);
 
@@ -69,17 +68,17 @@ TEST_F(TestsMechanism, selecting_profile_file) {
     {
         uint32_t extCount = 0;
         VkResult result = vkEnumerateInstanceExtensionProperties("VK_LAYER_KHRONOS_profiles", &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_TRUE(extCount >= 1);
 
         std::vector<VkExtensionProperties> ext(extCount);
         result = vkEnumerateInstanceExtensionProperties("VK_LAYER_KHRONOS_profiles", &extCount, ext.data());
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         bool found_ext = false;
         for (std::size_t i = 0, n = ext.size(); i < n; ++i) {
-            if (ext[i].extensionName == std::string("VK_EXT_layer_settings")) {
+            if (ext[i].extensionName == std::string(VK_EXT_LAYER_SETTINGS_EXTENSION_NAME)) {
                 found_ext = true;
                 break;
             }
@@ -88,6 +87,17 @@ TEST_F(TestsMechanism, selecting_profile_file) {
         EXPECT_TRUE(found_ext);
     }
 
+    err = inst_builder.init();
+    ASSERT_EQ(err, VK_SUCCESS);
+}
+
+TEST_F(TestsMechanism, selecting_profile_file) {
+    TEST_DESCRIPTION("Test selecting profile from a profiles file with multiple profiles");
+
+    VkResult err = VK_SUCCESS;
+
+    profiles_test::VulkanInstanceBuilder inst_builder;
+
     // Only override extensions
     {
         const char* profile_file_data = JSON_TEST_FILES_PATH "VP_LUNARG_test_device_extensions.json";
@@ -118,13 +128,13 @@ TEST_F(TestsMechanism, selecting_profile_file) {
 
         uint32_t extCount = 0;
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_EQ(1, extCount);
 
         std::vector<VkExtensionProperties> ext(extCount);
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, ext.data());
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_STREQ("VK_KHR_maintenance3", ext[0].extensionName);
 
@@ -161,13 +171,13 @@ TEST_F(TestsMechanism, selecting_profile_file) {
 
         uint32_t extCount = 0;
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_EQ(1, extCount);
 
         std::vector<VkExtensionProperties> ext(extCount);
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, ext.data());
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_STREQ("VK_KHR_maintenance3", ext[0].extensionName);
 
@@ -274,13 +284,13 @@ TEST_F(TestsMechanism, selecting_profile_dirs) {
 
         uint32_t extCount = 0;
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_EQ(1, extCount);
 
         std::vector<VkExtensionProperties> ext(extCount);
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, ext.data());
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_STREQ("VK_KHR_maintenance3", ext[0].extensionName);
 
@@ -321,8 +331,6 @@ TEST_F(TestsMechanism, selecting_profile_with_required_profiles) {
             return;
         }
 
-        VkResult result = VK_SUCCESS;
-
         VkPhysicalDeviceProperties2 gpu_props2{};
         gpu_props2.sType = VK_STRUCTURE_TYPE_PHYSICAL_DEVICE_PROPERTIES_2;
         gpu_props2.pNext = nullptr;
@@ -419,7 +427,7 @@ TEST_F(TestsMechanism, default_feature_values) {
         const char* default_feature_values_data = "DEFAULT_FEATURE_VALUES_FALSE";
         const char* debug_reports_data = "DEBUG_REPORT_MAX_ENUM";
 
-        std::vector<VkLayerSettingEXT> settings = {
+        const std::vector<VkLayerSettingEXT> settings = {
             {kLayerName, kLayerSettingsProfileFile, VK_LAYER_SETTING_TYPE_STRING_EXT, 1, &profile_file_data},
             {kLayerName, kLayerSettingsProfileName, VK_LAYER_SETTING_TYPE_STRING_EXT, 1, &profile_name_data},
             {kLayerName, kLayerSettingsEmulatePortability, VK_LAYER_SETTING_TYPE_BOOL32_EXT, 1, &emulate_portability_data},
