@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2021-2023 Valve Corporation
- * Copyright (C) 2021-2023 LunarG, Inc.
+ * Copyright (C) 2021-2024 Valve Corporation
+ * Copyright (C) 2021-2024 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,9 +14,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Author: Ziga Markus <ziga@lunarg.com>
- * Author: Christophe Riccio <christophe@lunarg.com>
- * Author: Mark Lobodzinski <mark@lunarg.com>
+ * Authors:
+ * - Ziga Markus <ziga@lunarg.com>
+ * - Christophe Riccio <christophe@lunarg.com>
+ * - Mark Lobodzinski <mark@lunarg.com>
  */
 
 #include <vulkan/vulkan_core.h>
@@ -164,7 +165,7 @@ TEST_F(TestsMechanismApiVersion, api_versions) {
 
         uint32_t extCount = 0;
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_EQ(0, extCount);
 
@@ -201,13 +202,13 @@ TEST_F(TestsMechanismApiVersion, api_versions) {
 
         uint32_t extCount = 0;
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_EQ(1, extCount);
 
         std::vector<VkExtensionProperties> ext(extCount);
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, ext.data());
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_STREQ(VK_KHR_PORTABILITY_SUBSET_EXTENSION_NAME, ext[0].extensionName);
 
@@ -244,13 +245,13 @@ TEST_F(TestsMechanismApiVersion, api_versions) {
 
         uint32_t extCount = 0;
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_EQ(23, extCount);
 
         std::vector<VkExtensionProperties> ext(extCount);
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, ext.data());
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
         ASSERT_EQ(ext.size(), extCount);
         std::array expected_extensions = {VK_KHR_MULTIVIEW_EXTENSION_NAME,
                                           VK_KHR_GET_PHYSICAL_DEVICE_PROPERTIES_2_EXTENSION_NAME,
@@ -319,13 +320,13 @@ TEST_F(TestsMechanismApiVersion, api_versions) {
 
         uint32_t extCount = 0;
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_EQ(24, extCount);
 
         std::vector<VkExtensionProperties> ext(extCount);
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, ext.data());
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
         ASSERT_EQ(ext.size(), extCount);
         std::array expected_extensions = {VK_KHR_MULTIVIEW_EXTENSION_NAME,
                                           VK_KHR_GET_PHYSICAL_DEVICE_PROPERTIES_2_EXTENSION_NAME,
@@ -395,13 +396,13 @@ TEST_F(TestsMechanismApiVersion, api_versions) {
 
         uint32_t extCount = 0;
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_EQ(47, extCount);
 
         std::vector<VkExtensionProperties> ext(extCount);
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, ext.data());
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
         ASSERT_EQ(ext.size(), extCount);
         std::array expected_extensions = {VK_KHR_MULTIVIEW_EXTENSION_NAME,
                                           VK_KHR_GET_PHYSICAL_DEVICE_PROPERTIES_2_EXTENSION_NAME,
@@ -465,6 +466,7 @@ TEST_F(TestsMechanismApiVersion, api_versions) {
     }
 
     // Vulkan 1.3
+#ifndef __APPLE__
     {
         const char* profile_file_data = JSON_TEST_FILES_PATH "VP_LUNARG_test_api_1_3.json";
         const char* profile_name_data = "VP_LUNARG_test_api_1_3";
@@ -494,13 +496,13 @@ TEST_F(TestsMechanismApiVersion, api_versions) {
 
         uint32_t extCount = 0;
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, nullptr);
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
 
         EXPECT_EQ(70, extCount);
 
         std::vector<VkExtensionProperties> ext(extCount);
         result = vkEnumerateDeviceExtensionProperties(gpu, nullptr, &extCount, ext.data());
-        ASSERT_EQ(err, VK_SUCCESS);
+        ASSERT_EQ(result, VK_SUCCESS);
         ASSERT_EQ(ext.size(), extCount);
         std::array expected_extensions = {VK_KHR_MULTIVIEW_EXTENSION_NAME,
                                           VK_KHR_GET_PHYSICAL_DEVICE_PROPERTIES_2_EXTENSION_NAME,
@@ -585,4 +587,5 @@ TEST_F(TestsMechanismApiVersion, api_versions) {
 
         inst_builder.reset();
     }
+#endif//__APPLE__
 }
