@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 2021-2023 Valve Corporation
- * Copyright (c) 2021-2023 LunarG, Inc.
+ * Copyright (c) 2021-2024 Valve Corporation
+ * Copyright (c) 2021-2024 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,15 +15,15 @@
  * limitations under the License.
  *
  * Authors:
- * - Daniel Rakos <daniel.rakos@rastergrid.com>
  * - Christophe Riccio <christophe@lunarg.com>
+ * - Daniel Rakos <daniel.rakos@rastergrid.com>
  */
 
 #include "mock_vulkan_api.hpp"
 #include "mock_debug_message_callback.hpp"
 #include <vulkan/vulkan_android.h>
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
 #include <vulkan/debug/vulkan_profiles.hpp>
 #else
 #include <vulkan/vulkan_profiles.hpp>
@@ -32,11 +32,8 @@
 TEST(mocked_api_get_physdev_profile_support, vulkan10_supported) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
     MockDebugMessageCallback cb({
-        "Checking device support for profile VP_ANDROID_baseline_2021 "
-        "(deviceName=, driverName=, driverInfo=). You may find the details "
-        "of the capabilities of this device on https://vulkan.gpuinfo.org/"
     });
 #endif
 
@@ -210,11 +207,8 @@ TEST(mocked_api_get_physdev_profile_support, vulkan10_no_gpdp2) {
 TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_version) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
     MockDebugMessageCallback cb({
-        "Checking device support for profile VP_KHR_roadmap_2022 "
-        "(deviceName=, driverName=, driverInfo=). You may find the details "
-        "of the capabilities of this device on https://vulkan.gpuinfo.org/",
         "Unsupported API version: 1.3.204"
     });
 #endif
@@ -290,11 +284,8 @@ TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_version) {
 TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_extension) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
     MockDebugMessageCallback cb({
-        "Checking device support for profile VP_ANDROID_baseline_2021 "
-            "(deviceName=, driverName=, driverInfo=). You may find the details "
-            "of the capabilities of this device on https://vulkan.gpuinfo.org/",
         "Unsupported extension: VK_GOOGLE_display_timing"
     });
 #endif
@@ -384,11 +375,8 @@ TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_extension) {
 TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_feature) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
     MockDebugMessageCallback cb({
-        "Checking device support for profile VP_ANDROID_baseline_2021 "
-            "(deviceName=, driverName=, driverInfo=). You may find the details "
-            "of the capabilities of this device on https://vulkan.gpuinfo.org/",
         "Unsupported feature condition: VkPhysicalDeviceFeatures2KHR::features.sampleRateShading == VK_TRUE"
     });
 #endif
@@ -479,11 +467,8 @@ TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_feature) {
 TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_property) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
     MockDebugMessageCallback cb({
-        "Checking device support for profile VP_ANDROID_baseline_2021 "
-            "(deviceName=, driverName=, driverInfo=). You may find the details "
-            "of the capabilities of this device on https://vulkan.gpuinfo.org/",
         "Unsupported properties condition: VkPhysicalDeviceProperties2KHR::properties.limits.maxImageDimension2D >= 4096"
     });
 #endif
@@ -573,11 +558,8 @@ TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_property) {
 TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_format) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
     MockDebugMessageCallback cb({
-        "Checking device support for profile VP_ANDROID_baseline_2021 "
-            "(deviceName=, driverName=, driverInfo=). You may find the details "
-            "of the capabilities of this device on https://vulkan.gpuinfo.org/",
         "Unsupported format condition for VK_FORMAT_E5B9G9R9_UFLOAT_PACK32: "
             "VkFormatProperties2KHR::formatProperties.optimalTilingFeatures contains "
             "(VK_FORMAT_FEATURE_SAMPLED_IMAGE_BIT | "
@@ -661,11 +643,8 @@ TEST(mocked_api_get_physdev_profile_support, vulkan10_unsupported_format) {
 TEST(mocked_api_get_physdev_profile_support, vulkan11_unsupported_version) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
-    MockDebugMessageCallback cb(
-        {"Checking device support for profile VP_KHR_roadmap_2022 "
-         "(deviceName=, driverName=, driverInfo=). You may find the details "
-         "of the capabilities of this device on https://vulkan.gpuinfo.org/",
+#ifdef WITH_DEBUG_MESSAGES
+    MockDebugMessageCallback cb({
          "Unsupported API version: 1.3.204"});
 #endif
 
@@ -736,11 +715,8 @@ TEST(mocked_api_get_physdev_profile_support, vulkan11_unsupported_version) {
 TEST(mocked_api_get_physdev_profile_support, vulkan13_unsupported_extension) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
     MockDebugMessageCallback cb({
-        "Checking device support for profile VP_KHR_roadmap_2022 "
-            "(deviceName=, driverName=, driverInfo=). You may find the details "
-            "of the capabilities of this device on https://vulkan.gpuinfo.org/",
         "Unsupported extension: VK_KHR_global_priority"
     });
 #endif
@@ -780,11 +756,8 @@ TEST(mocked_api_get_physdev_profile_support, vulkan13_unsupported_extension) {
 TEST(mocked_api_get_physdev_profile_support, vulkan13_unsupported_feature) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
     MockDebugMessageCallback cb({
-        "Checking device support for profile VP_KHR_roadmap_2022 "
-            "(deviceName=, driverName=, driverInfo=). You may find the details "
-            "of the capabilities of this device on https://vulkan.gpuinfo.org/",
         "Unsupported feature condition: VkPhysicalDeviceFeatures2KHR::features.fullDrawIndexUint32 == VK_TRUE"
     });
 #endif
@@ -826,12 +799,10 @@ TEST(mocked_api_get_physdev_profile_support, vulkan13_unsupported_feature) {
 TEST(mocked_api_get_physdev_profile_support, vulkan13_unsupported_property) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
-    MockDebugMessageCallback cb(
-        {"Checking device support for profile VP_KHR_roadmap_2022 "
-         "(deviceName=, driverName=, driverInfo=). You may find the details "
-         "of the capabilities of this device on https://vulkan.gpuinfo.org/",
-         "Unsupported properties condition: VkPhysicalDeviceProperties2KHR::properties.limits.maxImageDimensionCube >= 8192"});
+#ifdef WITH_DEBUG_MESSAGES
+    MockDebugMessageCallback cb({
+        "Unsupported properties condition: VkPhysicalDeviceProperties2KHR::properties.limits.maxImageDimensionCube >= 8192"
+    });
 #endif
 
     mock.SetInstanceAPIVersion(VK_API_VERSION_1_3);
@@ -873,11 +844,8 @@ TEST(mocked_api_get_physdev_profile_support, vulkan13_unsupported_property) {
 TEST(mocked_api_get_physdev_profile_support, vulkan11_unsupported_format) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
+#ifdef WITH_DEBUG_MESSAGES
     MockDebugMessageCallback cb({
-        "Checking device support for profile VP_ANDROID_baseline_2021 "
-            "(deviceName=, driverName=, driverInfo=). You may find the details "
-            "of the capabilities of this device on https://vulkan.gpuinfo.org/",
         "Unsupported format condition for VK_FORMAT_E5B9G9R9_UFLOAT_PACK32: "
             "VkFormatProperties2KHR::formatProperties.optimalTilingFeatures contains "
             "(VK_FORMAT_FEATURE_SAMPLED_IMAGE_BIT | "
@@ -936,11 +904,9 @@ TEST(mocked_api_get_physdev_profile_support, vulkan11_unsupported_format) {
 TEST(mocked_api_get_physdev_profile_support, vulkan13_supported_queue_family) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
-    MockDebugMessageCallback cb(
-        {"Checking device support for profile VP_KHR_roadmap_2022 "
-         "(deviceName=, driverName=, driverInfo=). You may find the details "
-         "of the capabilities of this device on https://vulkan.gpuinfo.org/"});
+#ifdef WITH_DEBUG_MESSAGES
+    MockDebugMessageCallback cb({
+    });
 #endif
 
     // Unsupported version
@@ -1010,11 +976,9 @@ TEST(mocked_api_get_physdev_profile_support, vulkan13_supported_queue_family) {
 TEST(mocked_api_get_physdev_profile_support, vulkan13_supported_version) {
     MockVulkanAPI mock;
 
-#if WITH_DEBUG_MESSAGES
-    MockDebugMessageCallback cb(
-        {"Checking device support for profile VP_KHR_roadmap_2022 "
-         "(deviceName=, driverName=, driverInfo=). You may find the details "
-         "of the capabilities of this device on https://vulkan.gpuinfo.org/"});
+#ifdef WITH_DEBUG_MESSAGES
+    MockDebugMessageCallback cb({
+    });
 #endif
 
     // Unsupported version
